{% load url from future %}
{% load i18n %}
<a class="inbox-link" href="{% url 'private_messages:inbox' %}">{% blocktrans %}Inbox{% endblocktrans %}
<span class="badge">{% block unread_messages_count %}{{ unread_msgs|default:'' }}{% endblock %}</span></a>
