{% extends PYBB_TEMPLATE|default:"base.html" %}

{% load url from future %}

{% load i18n pybb_tags %}

{% block title %}{{ PYBB_DEFAULT_TITLE }}{% endblock title %}

{% block extra_head %}
    {{ block.super }}
    <!-- Feeds -->
    <link rel="alternate" type="application/atom+xml" href="{% url 'pybb:feed_posts' %}" title="{% trans "Latest posts on forum" %}" >
    <link rel="alternate" type="application/atom+xml" href="{% url 'pybb:feed_topics' %}" title="{% trans "Latest topics on forum" %}" >
{% endblock %}

{% block private_messages %}
    {% include "pybb/private_messages/links.html" %}
{% endblock %}

{% block breadcrumb %}
    {% include "pybb/breadcrumb.html" %}
{% endblock %}

{% block content %}{% endblock content %}
